@@ -9,8 +9,8 @@ relocate <- function(.data, ..., .before = NULL, .after = NULL) {
   data_names <- colnames(.data)
   col_pos <- select_positions(.data, ...)
 
-  .before <- if (missing(.before)) .before else deparse(substitute(.before))
-  .after <- if (missing(.after)) .after else deparse(substitute(.after))
+  .before <- deparse_var(.before)
+  .after <- deparse_var(.after)
   has_before <- !is.null(.before)
   has_after <- !is.null(.after)
 
@@ -32,6 +32,6 @@ relocate <- function(.data, ..., .before = NULL, .after = NULL) {
   col_pos <- col_pos[col_pos <= length(data_names)]
 
   res <- .data[col_pos]
-  if (has_groups(.data)) res <- set_groups(res, group_vars(.data))
+  if (has_groups(.data)) res <- set_groups(res, get_groups(.data))
   res
 }
