@@ -50,18 +50,29 @@ expect_equal(
   info = "Test that newly created variables are available immediately with mutate()"
 )
 
+expect_equal(
+  mtcars %>% mutate(1L),
+  {
+    res <- mtcars
+    res[, "1L"] <- 1L
+    res
+  },
+  info = "Test that unnamed conditions are evaluated"
+)
+
 # Grouped Operations
 expect_equal(
   mtcars %>% group_by(am, cyl) %>% mutate(mpg2 = mpg * 2) %>% ungroup(),
   {
     res <- mtcars
-    do.call(rbind, unname(lapply(
+    res <- do.call(rbind, unname(lapply(
       split(res, list(res$am , res$cyl)),
       function(x) {
         x[, "mpg2"] <- x$mpg * 2
         x
       }
     )))
+    res[rownames(mtcars), ]
   },
   info = "Test grouped mutations"
 )
